# NamedRanges

A collection of all the NamedRanges in the document that share a given name.

**Type:** object

## Properties

- **name** (string): The name that all the named ranges share.
- **namedRanges** (array of [NamedRange](namedrange.md)): The NamedRanges that share the same name.
